<?php

namespace Drupal\braintree_api\Event;

use Braintree\WebhookNotification;
use Symfony\Component\EventDispatcher\Event;

class BraintreeApiWebhookEvent extends Event {

  /**
   * A string representing the kind of Braintree Webhook.
   *
   * @var string
   */
  protected $kind;

  /**
   * The Braintree Webhook notification object. Object properties depend
   * on the kind of webhook.
   *
   * @var \Braintree\WebhookNotification
   */
  protected $webhookNotification;

  /**
   * BraintreeApiWebhookEvent constructor.
   *
   * @param string $kind
   *   A string representing the kind of Braintree Webhook.
   *
   * @param \Braintree\WebhookNotification $webhook_notification
   *   The Braintree Webhook notification object. Object properties depend
   *   on the kind of webhook.
   *
   * @see https://developers.braintreepayments.com/reference/general/webhooks/overview#notification-kinds
   *   For a list of possible kinds of webhooks.
   */
  public function __construct($kind, WebhookNotification $webhook_notification) {
    $this->kind = $kind;
    $this->webhookNotification = $webhook_notification;
  }

  /**
   * @return \Braintree\WebhookNotification
   */
  public function getWebhookNotification() {
    return $this->webhookNotification;
  }

  /**
   * @return string
   */
  public function getKind() {
    return $this->kind;
  }
}
